### Utility Scripts

This folder contains utility scripts designed to generate configurations as well as a `validate.py` file, used to run a parallel validation of the existing configs and their corresponding tasks. There is one file per task type. This code should not be packaged in a release.
